Minn Kota® 80 Terrova™ US2-45/i-Pilot® & Foot Pedal 24V / spinkat.ru

форум
+7(963)755-97-22
+7(978)100-77-06
e-mail: info@spinkat.ru
Войти/Зарегистрироваться

- Доставка по Москве
  и всей России
- Консультации
  экспертов

Корзина пока пуста
Блог
интересные записи
Погода
Посмотеть погоду
Главная Рыболовная электроника Электромоторы Minn Kota® 80 Terrova™ US2-45/i-Pilot® & Foot Pedal 24V

## Minn Kota® 80 Terrova™ US2-45/i-Pilot® & Foot Pedal 24V

Заполните все поля и нажмите кнопку «Отправить».

Ваше имя: |
Ваш e-mail: |
Сообщение: |
обновить |

Дополнительные фото:

Рейтинг:
Отзывы (0)

В наличии ()
(Перед оплатой уточните наличие у менеджера магазина)

163 290.00 руб. В корзину
Отложить

- Wish List
- Обзоры
- Задать вопрос эксперту

Производитель:Minn Kota США

###### Характеристики:

- Артикул: TERROVA80US2-45/i-Pilot

ОписаниеДополнительные товары(0)Отзывы(0)Видео (есть)Статьи(0)Обзоры(0)

Обязательный атрибут всех профессиональных спортсменов-рыболовов, незаменимая вещь, позволяет двигаться медленно вдоль стенок камыша, не занимая при этом рук. Мотор, работающий от 2-х аккумуляторов по 12 вольт, позволяет часами бесшумно двигаться по водоему, не распугивая при этом рыбу.

Система i-Pilot выполняет функции якоря без веревки, удерживая ваш катер на месте, благодаря точному приемнику GPS. Теперь вы можете не опасаться, что ваш якорь застрянет в корягах или что крупная рыба на вываживании замотает шнур за якорный фал! Теперь вам доступно якорение над любыми глубинами - хоть над Марианской впадиной! Также, вы можете запомнить трек, по которому только что двигались, и функция Track Back i-Pilot сама, автоматически, вернет вас в исходную точку и провезет еще раз по этому маршруту!

Управляющий мотором педальный узел позволяет легко двигаться на катере в нужном направлении, останавливаться и задерживаться на месте, при этом ваши руки остаются совершенно свободными и вы можете совершать забросы приманки, не пропустив ни одного интересного места!

Встроенная система контроля заряда аккумуляторов Digital Maximaizer вовремя известит вас о необходимости подзарядки.

Встроенный универсальный датчик эхолота US2 имеет возможности для подключения к эхолотам Humminbird, Lowranse, Garmin и др. И вы можете наблюдать на экране эхограмму непосредственно под вашим судном, а не то, что уже осталось за кормой!

Оставить отзыв

Заполните все поля и нажмите кнопку «Отправить».

Ваше имя: |
Ваш e-mail: |
Оценка: | 5 4 3 2
Отзыв: |
обновить |

## ???? ??? ????????

Email: |
??????: |

?????? ?????????????????????????

## ?????? ??????

???: |
Email: |
???????: |
??????: |
???????? |